# PyPiSearch
[![Downloads](https://pepy.tech/badge/pypisearch)](https://pepy.tech/project/pypisearch)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

One more replacement of temporarily deprecated pip search command implemented on regular expressions and uses [pypi site](https://pypi.org/) search line.

## Install and run
- Clone this repo and run `python pypisearch <query>`
- Install it by pip `pip install pypisearch` and run `python -m pypisearch <query>`
